<?php

namespace App\Entity;

use App\Repository\SocialLinkRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: SocialLinkRepository::class)]
class SocialLink
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $title = null;

    #[ORM\Column(length: 255)]
    private ?string $url = null;

    /**
     * @var Collection<SocialLinkRepository>
     */
    #[ORM\OneToMany(mappedBy: 'socialLink', targetEntity: SocialLinkAttributes::class)]
    private Collection $attributes;

    #[ORM\Column(type: Types::TEXT)]
    private ?string $svg = null;

    public function __construct()
    {
        $this->attributes = new ArrayCollection();
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getTitle(): ?string
    {
        return $this->title;
    }

    public function setTitle(string $title): self
    {
        $this->title = $title;

        return $this;
    }

    public function getUrl(): ?string
    {
        return $this->url;
    }

    public function setUrl(string $url): self
    {
        $this->url = $url;

        return $this;
    }

    /**
     * @return Collection<int, SocialLinkAttributes>
     */
    public function getAttributes(): Collection
    {
        return $this->attributes;
    }

    public function addAttribute(SocialLinkAttributes $attribute): self
    {
        if (!$this->attributes->contains($attribute)) {
            $this->attributes->add($attribute);
            $attribute->setSocialLink($this);
        }

        return $this;
    }

    public function removeAttribute(SocialLinkAttributes $attribute): self
    {
        if ($this->attributes->removeElement($attribute)) {
            // set the owning side to null (unless already changed)
            if ($attribute->getSocialLink() === $this) {
                $attribute->setSocialLink(null);
            }
        }

        return $this;
    }

    public function getSvg(): ?string
    {
        return $this->svg;
    }

    public function setSvg(string $svg): self
    {
        $this->svg = $svg;

        return $this;
    }
}
