<?php

namespace App\Service;

use Aws\Result;
use Aws\S3\S3Client;
use Psr\Http\Message\UriInterface;

class S3Service
{
    private S3Client $s3Client;
    public function __construct(
        string $s3Server,
        string $s3AccessKey,
        string $s3SecretKey,
        private string $s3Bucket,
        string $s3Region
    ) {
        $this->s3Client = new S3Client([
            'version' => '2006-03-01',
            'region'  => $s3Region,
            'endpoint' => $s3Server,
            'use_path_style_endpoint' => true,
            'credentials' => [
                'key'    => $s3AccessKey,
                'secret' => $s3SecretKey,
            ],
        ]);
    }

    public function generateSignedUrl(string $filename, int $expires = 60): string
    {
        $command = $this->s3Client->getCommand('GetObject', [
            'Bucket' => $this->s3Bucket,
            'Key'    => $filename
        ]);
        $presignedRequest = $this->s3Client->createPresignedRequest($command, $expires . ' minutes');
        return (string) $presignedRequest->getUri();
    }

    /** @phpstan-ignore-next-line */
    public function listFolder(string $path): Result
    {
        /** @phpstan-ignore-next-line */
        return $this->s3Client->ListObjectsV2(['Bucket' => $this->s3Bucket, 'Delimiter' => '/', 'Prefix' => $path]);
    }

    public function checkIfFileExists(string $path): bool
    {
        return $this->s3Client->doesObjectExist($this->s3Bucket, $path);
    }
}
