<?php

namespace App\Twig\Extensions;

use App\Service\MarkdownService;
use Symfony\Component\DependencyInjection\Attribute\AutoconfigureTag;
use Twig\Extension\AbstractExtension;
use Twig\TwigFilter;

#[AutoconfigureTag('twig.extension')]
class MarkdownParser extends AbstractExtension
{
    public function __construct(
        private readonly MarkdownService $converter
    ) {
    }

    public function getFilters()
    {
        return [
            new TwigFilter(
                'markdown_from_html',
                [$this, 'convert'],
                ['is_safe' => ['all']]
            ),
        ];
    }


    public function convert(string $body): string
    {
        // remove indentation
        if ($white = substr($body, 0, strspn($body, " \t\r\n\0\x0B"))) {
            $body = preg_replace("{^$white}m", '', $body);
        }

        return $this->converter->text($body);
    }
}
